@@ -1,8 +1,6 @@
 import logging
 import urllib.parse
 
-from tornado.ioloop import IOLoop
-
 from baiocas import errors
 from baiocas.channel_id import ChannelId
 from baiocas.message import Message
@@ -14,9 +12,8 @@ class Transport(object):
 
     OPTION_MAXIMUM_NETWORK_DELAY = 'maximum_network_delay'
 
-    def __init__(self, io_loop=None, **options):
+    def __init__(self, **options):
         self.log = logging.getLogger('%s.%s' % (self.__module__, self.name))
-        self.io_loop = io_loop or IOLoop.instance()
         self._client = None
         self._options = {}
         self.url = None
